@@ -1,4 +1,6 @@
-pub use async_trait::async_trait;
-pub mod error;
-pub mod pool;
+mod pool;
 pub mod resource;
+pub mod sync;
+
+pub use async_trait::async_trait;
+pub use pool::{Pool, Pooled};
